==> libcobra-java_0.97.4.orig.tar.gz: libcobra-java-0.97.4.orig/src/org/lobobrowser/html/domimpl/HTMLBaseFontElementImpl.java <==
/*
    GNU LESSER GENERAL PUBLIC LICENSE
    Copyright (C) 2006 The Lobo Project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Contact info: xamjadmin@users.sourceforge.net
*/
package org.lobobrowser.html.domimpl;

import org.lobobrowser.html.style.*;
import org.lobobrowser.util.gui.ColorFactory;
import org.w3c.dom.html2.HTMLBaseFontElement;

public class HTMLBaseFontElementImpl extends HTMLAbstractUIElement implements
		HTMLBaseFontElement {
	public HTMLBaseFontElementImpl(String name) {
		super(name);
	}

	public String getColor() {
		return this.getAttribute("color");
	}

	public String getFace() {
		return this.getAttribute("face");
	}

	public void setColor(String color) {
		this.setAttribute("color", color);
	}

	public void setFace(String face) {
		this.setAttribute("face", face);
	}

	public int getSize() {
		try {
			return Integer.parseInt(this.getAttribute("size"));
		} catch(Exception thrown) {
			this.warn("getSize(): Unable to parse size attribute in " + this + ".", thrown);
			return 0;
		}
	}

	public void setSize(int size) {
		this.setAttribute("size", String.valueOf(size));
	}
	
	protected RenderState createRenderState(RenderState prevRenderState) {
		String face = this.getAttribute("face");
		String size = this.getAttribute("size");
		String color = this.getAttribute("color");
		if(face != null) {
			prevRenderState = new FontNameRenderState(prevRenderState, face);
		}
		if(size != null) {
			int fontNumber = HtmlValues.getFontNumberOldStyle(size, prevRenderState);
			float fontSize = HtmlValues.getFontSize(fontNumber);
			prevRenderState = new FontSizeRenderState(prevRenderState, fontSize);
			prevRenderState = new BaseFontRenderState(prevRenderState, fontNumber);
		}
		if(color != null) {
			prevRenderState = new ColorRenderState(prevRenderState, ColorFactory.getInstance().getColor(color));
		}
		return prevRenderState;
	}

}

==> libcobra-java_0.98.2.orig.tar.gz: libcobra-java-0.98.2.orig/src/org/lobobrowser/html/domimpl/HTMLBaseFontElementImpl.java <==
/*
    GNU LESSER GENERAL PUBLIC LICENSE
    Copyright (C) 2006 The Lobo Project

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Contact info: lobochief@users.sourceforge.net
*/
package org.lobobrowser.html.domimpl;

import org.lobobrowser.html.style.*;
import org.lobobrowser.util.gui.ColorFactory;
import org.w3c.dom.html2.HTMLBaseFontElement;

public class HTMLBaseFontElementImpl extends HTMLAbstractUIElement implements
		HTMLBaseFontElement {
	public HTMLBaseFontElementImpl(String name) {
		super(name);
	}

	public String getColor() {
		return this.getAttribute("color");
	}

	public String getFace() {
		return this.getAttribute("face");
	}

	public void setColor(String color) {
		this.setAttribute("color", color);
	}

	public void setFace(String face) {
		this.setAttribute("face", face);
	}

	public int getSize() {
		try {
			return Integer.parseInt(this.getAttribute("size"));
		} catch(Exception thrown) {
			this.warn("getSize(): Unable to parse size attribute in " + this + ".", thrown);
			return 0;
		}
	}

	public void setSize(int size) {
		this.setAttribute("size", String.valueOf(size));
	}
	
	protected RenderState createRenderState(RenderState prevRenderState) {
		String face = this.getAttribute("face");
		String size = this.getAttribute("size");
		String color = this.getAttribute("color");
		if(face != null) {
			prevRenderState = new FontNameRenderState(prevRenderState, face);
		}
		if(size != null) {
			int fontNumber = HtmlValues.getFontNumberOldStyle(size, prevRenderState);
			float fontSize = HtmlValues.getFontSize(fontNumber);
			prevRenderState = new FontSizeRenderState(prevRenderState, fontSize);
			prevRenderState = new BaseFontRenderState(prevRenderState, fontNumber);
		}
		if(color != null) {
			prevRenderState = new ColorRenderState(prevRenderState, ColorFactory.getInstance().getColor(color));
		}
		return prevRenderState;
	}

}
